@@ -121,7 +121,7 @@ class Address(AbstractAddress):
         with transaction.atomic():
             try:
                 self.street = self.get_or_create_street()
-                return self.Address.objects.get_or_create(
+                address, _ = self.Address.objects.get_or_create(
                     locality=self.street.locality,  # noqa
                     street=self.street,
                     raw=self.raw,
@@ -132,5 +132,6 @@ class Address(AbstractAddress):
                     longitude=self.longitude,
                     apartment=self.apartment,
                 )
+                return address
             except Exception as error:
                 raise AddressError from error
